# anysqlite

[![PyPI - Version](https://img.shields.io/pypi/v/anysqlite.svg)](https://pypi.org/project/anysqlite)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/anysqlite.svg)](https://pypi.org/project/anysqlite)

-----

## Installation

```console
pip install anysqlite
```
